summaryrefslogtreecommitdiffhomepage
path: root/examples/advanced.c
diff options
context:
space:
mode:
Diffstat (limited to 'examples/advanced.c')
-rw-r--r--examples/advanced.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/advanced.c b/examples/advanced.c
index 391230f6..728e056f 100644
--- a/examples/advanced.c
+++ b/examples/advanced.c
@@ -34,9 +34,9 @@ static inline VikingRaw viking_toRaw(Viking* vk) {
VikingRaw raw = {vk->name.str, vk->country.str}; return raw;
}
-// With this in place, we use the using_cmap_keyarg() macro to define {Viking -> int} hash map type:
+// With this in place, we use the using_cmap_keydef() macro to define {Viking -> int} hash map type:
-using_cmap_keyarg(vk, Viking, int, vikingraw_equals, vikingraw_hash,
+using_cmap_keydef(vk, Viking, int, vikingraw_equals, vikingraw_hash,
viking_del, viking_fromRaw, viking_toRaw, VikingRaw);
int main()